

set -ex



pushd libs/python/example/tutorial
export CONDA_BUILD=1
bjam -q -d+2 --debug --debug-configuration
python -c 'from __future__ import print_function; import hello_ext; print(hello_ext.greet())'
popd
test -f $PREFIX/include/boost/python.hpp
test -d $PREFIX/include/boost/python
test -f $PREFIX/lib/libboost_python.a
test -f $PREFIX/lib/libboost_python38.a
test -f $PREFIX/lib/libboost_python.so
test -f $PREFIX/lib/libboost_python38.so
test -f $PREFIX/lib/libboost_numpy.a
test -f $PREFIX/lib/libboost_numpy38.a
test -f $PREFIX/lib/libboost_numpy.so
test -f $PREFIX/lib/libboost_numpy38.so
exit 0
